import logging

from dockerscan import get_log_level, run_in_console

from .api import *
from .model import *

log = logging.getLogger('dockerscan')


def launch_dockerscan_scan_in_console(config: DockerScanModel):
    """Launch in console mode"""

    log.setLevel(get_log_level(config.verbosity))

    with run_in_console(config.debug):
        run_scan_dockerscan(config)

__all__ = ("launch_dockerscan_scan_in_console",)



import logging

from contextlib import contextmanager

log = logging.getLogger("dockerscan")


@contextmanager
def run_in_console(debug=False):
    try:
        yield
    except Exception as e:
        log.critical(" !! {}".format(e))

        if debug:
            log.exception(" !! Unhandled exception: %s" % e, stack_info=True)
    finally:
        log.debug("Shutdown...")



"""
This file contains utils and reusable functions
"""

import logging

from collections import namedtuple


def dict_to_obj(data):
    """
    Transform an input dict into a object.

    >>> data = dict(hello="world", bye="see you")
    >>> obj = dict_to_obj(data)
    >>> obj.hello
    'world'

    :param data: input dictionary data
    :type data: dict
    """
    assert isinstance(data, dict)

    if not data:
        return namedtuple("OBJ", [])

    obj = namedtuple("OBJ", list(data.keys()))

    return obj(**data)


def get_log_level(verbosity: int) -> int:
    verbosity *= 10

    if verbosity > logging.CRITICAL:
        verbosity = logging.CRITICAL

    if verbosity < logging.DEBUG:
        verbosity = logging.DEBUG

    return (logging.CRITICAL - verbosity) + 10


__all__ = ("dict_to_obj", "get_log_level")



import click

# from .console import launch_dockerscan_scan_in_console


@click.command(help="Search for Open Docker Registries (still not avaible)")
@click.pass_context
# @click.option("--scan")
# @click.option("--shodan", "-S")
# @click.option("--mrlooquer", "-M")
def discover(ctx, **kwargs):
    # launch_dockerscan_scan_in_console(ctx.obj, **kwargs)
    pass
